Learn R Programming

inegiR (version 2.0.0)

inegi_catalog: INEGI Catalog

Description

A dataset containing some INEGI codes from the most common data requests. This has been collected by manually searching the BIE Website in INEGI, as no official catalog exists.

Usage

inegi_catalog

Arguments

Value

data.frame

Format

A data frame with 54 rows and 10 variables:

NAME

Name of data indicador, possibly in spanish

LEVEL_2

Level 2 of desagregation

LEVEL_3

Level 3 of desagregation

LEVEL_4

Level 4 of desagregation

UNITS

Units

BASE

If they are constant units this is the base year

FREQUENCY

Frequency

INEGI_CODE

Numeric INEGI code

GROUP

Group of codes, manually updated

INEGI_SERIES

Series in the form of URL to pass to inegi_series()