A dataset containing some INEGI codes from the most common data requests. This has been collected by manually searching the BIE Website in INEGI, as no official catalog exists.
inegi_catalogdata.frame
A data frame with 54 rows and 10 variables:
Name of data indicador, possibly in spanish
Level 2 of desagregation
Level 3 of desagregation
Level 4 of desagregation
Units
If they are constant units this is the base year
Frequency
Numeric INEGI code
Group of codes, manually updated
Series in the form of URL to pass to inegi_series()